/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*             UNIDAD DE EVALUACIN DEL SISTEMA EDUCATIVO NACIONAL
/*             DIRECCIN GENERAL DE MEDICIN Y TRATAMIENTO DE DATOS
/*
/*                      DIRECCIN DE TRATAMIENTO DE DATOS
/*
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                     TERCER GRADO DE SECUNDARIA (Excale 09)
/*
/*                              **** ESCUELAS ****
/*
/*                     Ciclo escolar evaluado: 2011 - 2012
/*_____________________________________________________________________________
/*
/*
/*        SINTAXIS PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE ESCUELAS
/*                                  EN FORMATO SPSS
/*_____________________________________________________________________________
/*
/*  La sintaxis convierte al archivo Excale09_2012_Escuelas.txt, el cual est en
/*  formato ASCII, en una base de datos en formato SPSS. La sintaxis realiza las
/*  siguientes tareas:
/*   - Lee las variables del archivo en formato ASCII
/*   - Etiqueta las variables as como sus valores
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale09_2012_Escuelas.txt
/*         as como el archivo Excale09_2012_Escuelas.SPS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primer lnea de los comandos de este archivo
/*         (CD "C:\***") para actualizar el nombre del directorio de trabajo.
/*      3) Ejecutar toda la sintaxis del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale09_2012_Escuelas.SAV
/*
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Direccin de Tratamiento de Datos
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 18 DE MARZO DEL 2014
/*
/*  ****************************************************************************/

    /* Actualizar el nombre del directorio donde se ubica el archivo Excale09_2012_Escuelas.TXT */
  CD "C:\***"


SET DECIMAL=DOT.
DATA LIST FILE = "Excale09_2012_Escuelas.TXT"
       /PROYECTO         1 - 6      (a)
        AO              7 - 10
        ESCUELA         11 - 14
        ID_ENT          15 - 16
        NOM_ENT         17 - 35     (a)
        ID_TURNO        36 - 36
        TURNO_ESC       37 - 47     (a)
        ID_MOD          48 - 48
        MOD             49 - 52     (a)
        ENTEST          53 - 58     (a)
        ALU_ESC         59 - 61
        ALU_SHI         62 - 63
        ESC_UH          64 - 67
.



/***********************************************************************
/* Etiqueta variables
/*
/**********************************************************************.

VARIABLE LABELS
      PROYECTO      "Proyecto al que pertenece el estudio"
      AO           "Ao del levantamiento de datos"
      ESCUELA       "Identificador de la escuela"
      ID_ENT        "Entidad federativa (identificador numrico)"
      NOM_ENT       "Entidad federativa"
      ID_TURNO      "Turno de la escuela (numrico)"
      TURNO_ESC     "Turno de la escuela"
      ID_MOD        "Estrato escolar o Modalidad educativa (identificador numrico)"
      MOD           "Estrato escolar o Modalidad educativa"
      ENTEST        "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad)"
      ALU_ESC       "Cantidad de alumnos de 3o de secundaria en la escuela"
      ALU_SHI       "Cantidad de alumnos evaluados en la escuela"
      ESC_UH        "Cantidad de escuelas en el estrato muestral ENTEST"
.



/***********************************************************************
/* Etiquetas de valores.
/*
/**********************************************************************.

 VALUE LABELS
       ID_ENT    1      "Aguascalientes"
                 2      "Baja California"
                 3      "Baja California Sur"
                 4      "Campeche"
                 5      "Coahuila"
                 6      "Colima"
                 7      "Chiapas"
                 8      "Chihuahua"
                 9      "Distrito Federal"
                 10     "Durango"
                 11     "Guanajuato"
                 12     "Guerrero"
                 13     "Hidalgo"
                 14     "Jalisco"
                 15     "Mxico"
                 16     "Michoacn"
                 17     "Morelos"
                 18     "Nayarit"
                 19     "Nuevo Len"
                 20     "Oaxaca"
                 21     "Puebla"
                 22     "Quertaro"
                 23     "Quintana Roo"
                 24     "San Luis Potos"
                 25     "Sinaloa"
                 26     "Sonora"
                 27     "Tabasco"
                 28     "Tamaulipas"
                 29     "Tlaxcala"
                 30     "Veracruz"
                 31     "Yucatn"
                 32     "Zacatecas"/
      ID_TURNO
                 1      "Matutino"
                 2      "Vespertino"
                 3      "Nocturno"
                 4      "Discontinuo"
                 5      "Mixto"/
      ID_MOD
                 6      "General"
                 7      "Tcnica"
                 8      "Telesecundaria"
                 9      "Privada"/
      MOD
                 "GRAL" "General"
                 "TEC"  "Tcnica"
                 "TV"   "Telesecundaria"
                 "PRIV" "Privada"/
      ENTEST
                 "999999"   "Respuesta omitida"
.




/***********************************************************************
/* Valores perdidos.
/*
/**********************************************************************.

MISSING VALUES
       ENTEST     ("999999")
.





/***********************************************************************
/* Guarda el Archivo.
/*
/**********************************************************************.


SAVE OUTFILE="Excale09_2012_Escuelas.SAV".
EXE.

